#

##

##

    	format

    	kinds

    		point:

    		blob:

    		line:

    	possibilities

    		DB:geo_map
    			collection:places [{
    					"name": [ "soccer field" ],
    					"place": {
    						"UTC": "2094-04-27T10:48:12Z",
    						"field": [{
    							"longitude": "",
    							"latitude": ""
    						}]
    					}
    				}]

    		{
    			"names": [ "Tuesday" ],
    			"when": {}
    		}

    		{
    			"names": [ "January" ],
    			"every": {
    				"helix": "UTC",
    				"month": "January"
    			}
    		}

    		{
    			"names": [ "week 52" ],
    			"every": {
    				"helix": "UTC",
    				"week of year": 52
    			}
    		}